# mensa-kl-cli
Commandline interface for the Mensa at TUKL

## Usage

From a terminal after installation: `mensa-kl`

## Command line switches

`--week`

Display full week

`--today`

Display only today

`--vegetarian`

Display only vegetarian options
